--- app_chanspy_original.c	2007-06-26 11:33:05.000000000 -0400
+++ app_chanspy.c	2007-06-27 11:42:41.000000000 -0400
@@ -83,6 +83,9 @@
 "    W             - Enable 'private whisper' mode, so the spying channel can\n"
 "                    talk to the spied-on channel but cannot listen to that\n"
 "                    channel.\n"
+"    e(ext)	   - Enable 'enforced' mode, so that the spying channel can\n"
+"		     only monitor extensions whose name is in the 'ext' :\n"
+"		     delimited list.\n"
 ;
 
 static const char *app_ext = "ExtenSpy";
@@ -121,12 +124,14 @@
 	OPTION_RECORD    = (1 << 4),
 	OPTION_WHISPER	 = (1 << 5),
 	OPTION_PRIVATE   = (1 << 6),	/* Private Whisper mode */
+	OPTION_ENFORCED  = (1 << 7),    /* Enforced mode */
 } chanspy_opt_flags;
 
 enum {
 	OPT_ARG_VOLUME = 0,
 	OPT_ARG_GROUP,
 	OPT_ARG_RECORD,
+	OPT_ARG_ENFORCED,
 	OPT_ARG_ARRAY_SIZE,
 } chanspy_opt_args;
 
@@ -138,6 +143,7 @@
 	AST_APP_OPTION_ARG('v', OPTION_VOLUME, OPT_ARG_VOLUME),
 	AST_APP_OPTION_ARG('g', OPTION_GROUP, OPT_ARG_GROUP),
 	AST_APP_OPTION_ARG('r', OPTION_RECORD, OPT_ARG_RECORD),
+	AST_APP_OPTION_ARG('e', OPTION_ENFORCED, OPT_ARG_ENFORCED),
 });
 
 
@@ -425,7 +431,7 @@
 }
 
 static int common_exec(struct ast_channel *chan, const struct ast_flags *flags,
-		       int volfactor, const int fd, const char *mygroup, const char *spec,
+		       int volfactor, const int fd, const char *mygroup, const char *myenforced, const char *spec,
 		       const char *exten, const char *context)
 {
 	struct ast_channel *peer, *prev, *next;
@@ -473,7 +479,12 @@
 			char *groups[25];
 			int num_groups = 0;
 			char *dup_group;
+			char *form_enforced;
+			int ienf = !myenforced;
+			char *ext;
 			int x;
+			int y;
+			int z;
 			char *s;
 				
 			if (peer == prev)
@@ -506,6 +517,48 @@
 			if (!igrp)
 				continue;
 
+			if (myenforced) {
+
+
+				ext = malloc(strlen(peer->name));
+				form_enforced = malloc(strlen(myenforced) + 3);
+
+				strcpy(form_enforced, ":");
+				strcat(form_enforced, myenforced);
+				strcat(form_enforced, ":");
+				
+				ext[0] = ':';
+
+				for (x = 0; x < strlen(peer->name); x++) {
+					if (peer->name[x] == '/')
+						break;
+				}
+				
+				z = 1;
+		
+				for (y = x+1; y < strlen(peer->name); y++) {
+					if (peer->name[y] != '-') {
+						ext[z] = peer->name[y];
+						z++;
+					} else {
+						
+						ext[z] = ':';
+						ext[z+1] = '\0';
+						break;
+					}
+				}
+
+				if (strstr(form_enforced, ext))
+					ienf = 1;
+				
+				free(form_enforced);
+				free(ext);
+
+			}
+			
+			if (!ienf)
+				continue;
+
 			strcpy(peer_name, "spy-");
 			strncat(peer_name, peer->name, AST_NAME_STRLEN);
 			ptr = strchr(peer_name, '/');
@@ -561,6 +614,7 @@
 	char *spec = NULL;
 	char *argv[2];
 	char *mygroup = NULL;
+	char *myenforced = NULL;
 	char *recbase = NULL;
 	int fd = 0;
 	struct ast_flags flags;
@@ -604,6 +658,10 @@
 
 		if (ast_test_flag(&flags, OPTION_PRIVATE))
 			ast_set_flag(&flags, OPTION_WHISPER);
+		
+		if (ast_test_flag(&flags, OPTION_ENFORCED))
+			myenforced = opts[OPT_ARG_ENFORCED];
+		
 	}
 
 	oldwf = chan->writeformat;
@@ -623,7 +681,9 @@
 		}
 	}
 
-	res = common_exec(chan, &flags, volfactor, fd, mygroup, spec, NULL, NULL);
+	ast_log(LOG_NOTICE, "This myenforced is sent: %s\n",myenforced);
+
+	res = common_exec(chan, &flags, volfactor, fd, mygroup, myenforced, spec, NULL, NULL);
 
 	if (fd)
 		close(fd);
@@ -707,7 +767,7 @@
 		}
 	}
 
-	res = common_exec(chan, &flags, volfactor, fd, mygroup, NULL, exten, context);
+	res = common_exec(chan, &flags, volfactor, fd, mygroup, NULL, NULL, exten, context);
 
 	if (fd)
 		close(fd);
